﻿// ===============================================================================
//  解决方案：网鸟基础类库
//  项目名称：Net.Htmlbird.Framework
//  文件名称：ColoredEnumDescriptionAttribute.cs
//  代码作者：网鸟老兵团(Me.YMind)
//  创建时间：2011-11-14 17:44
// ===============================================================================

using System;
using System.Text;

namespace Net.Htmlbird.Framework
{
	/// <summary>
	/// 指定带有颜色注释信息的枚举值的说明。
	/// </summary>
	[AttributeUsage(AttributeTargets.Enum | AttributeTargets.Field, AllowMultiple = false, Inherited = true)]
	public sealed class ColoredEnumDescriptionAttribute : EnumDescriptionAttribute
	{
		/// <summary>
		/// 初始化 <see cref="ColoredEnumDescriptionAttribute"/> 类的新实例并带有说明。
		/// </summary>
		/// <param name="description">说明文本。</param>
		public ColoredEnumDescriptionAttribute(string description) : this(description, null) { }

		/// <summary>
		/// 初始化 <see cref="ColoredEnumDescriptionAttribute"/> 类的新实例并带有说明。
		/// </summary>
		/// <param name="description">说明文本。</param>
		/// <param name="foreColor">前景色。</param>
		public ColoredEnumDescriptionAttribute(string description, string foreColor) : this(description, foreColor, null) { }

		/// <summary>
		/// 初始化 <see cref="ColoredEnumDescriptionAttribute"/> 类的新实例并带有说明。
		/// </summary>
		/// <param name="description">说明文本。</param>
		/// <param name="foreColor">前景色。</param>
		/// <param name="backColor">背景色。</param>
		public ColoredEnumDescriptionAttribute(string description, string foreColor, string backColor) : this(description, foreColor, backColor, null) { }

		/// <summary>
		/// 初始化 <see cref="ColoredEnumDescriptionAttribute"/> 类的新实例并带有说明。
		/// </summary>
		/// <param name="description">说明文本。</param>
		/// <param name="foreColor">前景色。</param>
		/// <param name="backColor">背景色。</param>
		/// <param name="id">指定 HTML 标签中的 id 特性字段的值。</param>
		public ColoredEnumDescriptionAttribute(string description, string foreColor, string backColor, string id) : this(description, foreColor, backColor, id, null) { }

		/// <summary>
		/// 初始化 <see cref="ColoredEnumDescriptionAttribute"/> 类的新实例并带有说明。
		/// </summary>
		/// <param name="description">说明文本。</param>
		/// <param name="foreColor">前景色。</param>
		/// <param name="backColor">背景色。</param>
		/// <param name="id">指定 HTML 标签中的 id 特性字段的值。</param>
		/// <param name="target">指定 HTML 标签中的 target 特性字段的值。</param>
		public ColoredEnumDescriptionAttribute(string description, string foreColor, string backColor, string id, string target) : base(description)
		{
			this.ForeColor = foreColor ?? String.Empty;
			this.BackColor = backColor ?? String.Empty;
			this.Id = id ?? String.Empty;
			this.Target = target ?? String.Empty;
		}

		/// <summary>
		/// 获取或设置前景色。
		/// </summary>
		public string ForeColor { get; set; }

		/// <summary>
		/// 获取或设置背景色。
		/// </summary>
		public string BackColor { get; set; }

		/// <summary>
		/// 获取或设置 HTML 标签中的 id 特性字段的值。
		/// </summary>
		public string Id { get; set; }

		/// <summary>
		/// 获取或设置 HTML 标签中的 target 特性字段的值。
		/// </summary>
		public string Target { get; set; }

		/// <summary>
		/// 返回当前对象的 HTML 表示形式。
		/// </summary>
		/// <param name="baseUrl">基础链接地址。可以为空。</param>
		/// <param name="tagName">标签名称。</param>
		/// <returns>返回 <see cref="System.String"/>。</returns>
		public string ToHTML(string baseUrl = null, string tagName = "span")
		{
			var html = new StringBuilder();

			html.Append('<');

			if (String.IsNullOrWhiteSpace(baseUrl)) html.Append(tagName);
			else
			{
				tagName = "a";

				html.Append(tagName);
				html.Append(@" href=""");
				html.Append(baseUrl);
				html.Append(@"""");

				if (String.IsNullOrWhiteSpace(this.Id) == false)
				{
					html.Append(@" id=""");
					html.Append(this.Id);
					html.Append(@"""");
				}

				if (String.IsNullOrWhiteSpace(this.Target) == false)
				{
					html.Append(@" targetid=""");
					html.Append(this.Target);
					html.Append(@"""");
				}
			}

			if (!String.IsNullOrWhiteSpace(this.ForeColor) || !String.IsNullOrWhiteSpace(this.BackColor))
			{
				html.Append(@" style=""");

				if (String.IsNullOrWhiteSpace(this.ForeColor) == false)
				{
					html.Append("color:");
					html.Append(this.ForeColor);
					html.Append(";");
				}

				if (String.IsNullOrWhiteSpace(this.BackColor) == false)
				{
					html.Append("background-color:");
					html.Append(this.BackColor);
					html.Append(";");
				}

				html.Append(@"""");
			}

			html.Append(@">");
			html.Append(this.Description);
			html.Append("</");
			html.Append(tagName);
			html.Append(">");

			return html.ToString();
		}
	}
}
