﻿// ===============================================================================
//  解决方案：网鸟基础类库
//  项目名称：Net.Htmlbird.Framework
//  文件名称：EnumDescriptionAttribute.cs
//  代码作者：网鸟老兵团(Me.YMind)
//  创建时间：2011-11-14 17:44
// ===============================================================================

using System;
using System.ComponentModel;

namespace Net.Htmlbird.Framework
{
	/// <summary>
	/// 指定枚举值的说明。
	/// </summary>
	[AttributeUsage(AttributeTargets.Enum | AttributeTargets.Field, AllowMultiple = false, Inherited = true)]
	public class EnumDescriptionAttribute : DescriptionAttribute
	{
		/// <summary>
		/// 初始化 <see cref="EnumDescriptionAttribute"/> 类的新实例并带有说明。
		/// </summary>
		/// <param name="description">说明文本。</param>
		public EnumDescriptionAttribute(string description) { this.SetDescription(description); }

		/// <summary>
		/// 获取或设置用户自定义内容。
		/// </summary>
		public object[] UserOptions { get; set; }

		/// <summary>
		/// 设置说明文本为指定值。
		/// </summary>
		/// <param name="description">说明文本。</param>
		public void SetDescription(string description)
		{
			if (description == null) throw new ArgumentNullException("description");
			if (description.Length == 0) throw new ArgumentOutOfRangeException("description");

			this.DescriptionValue = description;
		}
	}
}
